@@ -10,18 +10,25 @@ null_equal <- function(x, y) {
 }
 
 load_pymagic <- function(delay_load = FALSE) {
+  # load
   if (is.null(pymagic)) {
+    # first time load
     result <- try(pymagic <<- reticulate::import("magic", delay_load = delay_load))
   } else {
+    # already loaded
     result <- try(reticulate::import("magic", delay_load = delay_load))
   }
+  # check
   if (methods::is(result, "try-error")) {
+    # failed load
     if ((!delay_load) && length(grep("ModuleNotFoundError: No module named 'magic'", result)) > 0 ||
         length(grep("ImportError: No module named magic", result)) > 0) {
+      # not installed
       if (utils::menu(c("Yes", "No"), title="Install MAGIC Python package with reticulate?") == 1) {
         install.magic()
       }
     } else if (length(grep("r\\-reticulate", reticulate::py_config()$python)) > 0) {
+      # installed, but envs sometimes give weird results
       message("Consider removing the 'r-reticulate' environment by running:")
       if (grep("virtualenvs", reticulate::py_config()$python)) {
         message("reticulate::virtualenv_remove('r-reticulate')")
@@ -29,6 +36,18 @@ load_pymagic <- function(delay_load = FALSE) {
         message("reticulate::conda_remove('r-reticulate')")
       }
     }
+  } else if (!delay_load) {
+    # successful load
+    version <- strsplit(pymagic$`__version__`, '\\.')[[1]]
+    major_version <- 1
+    minor_version <- 4
+    if (as.integer(version[1]) < major_version) {
+      stop(paste0("Python MAGIC version ", pymagic$`__version__`, " is out of date (recommended: ", 
+                  major_version, ".", minor_version, "). Please update with pip or Rmagic::install.magic()."))
+    } else if (as.integer(version[2]) < minor_version) {
+      warning(paste0("Python MAGIC version ", pymagic$`__version__`, " is out of date (recommended: ", 
+                     major_version, ".", minor_version, "). Consider updating with pip or Rmagic::install.magic()."))
+    }
   }
 }
 
